[data-simplebar]{flex-flow:column wrap;place-content:flex-start;align-items:flex-start;position:relative}.simplebar-wrapper{width:inherit;height:inherit;max-width:inherit;max-height:inherit;overflow:hidden}.simplebar-mask{direction:inherit;z-index:0;margin:0;padding:0;position:absolute;inset:0;overflow:hidden;width:auto!important;height:auto!important}.simplebar-offset{-webkit-overflow-scrolling:touch;margin:0;padding:0;position:absolute;inset:0;direction:inherit!important;box-sizing:inherit!important;resize:none!important}.simplebar-content-wrapper{direction:inherit;scrollbar-width:none;-ms-overflow-style:none;width:auto;max-width:100%;height:100%;max-height:100%;display:block;position:relative;overflow:auto;box-sizing:border-box!important}.simplebar-content-wrapper::-webkit-scrollbar{width:0;height:0;display:none}.simplebar-hide-scrollbar::-webkit-scrollbar{width:0;height:0;display:none}.simplebar-content:after,.simplebar-content:before{content:" ";display:table}.simplebar-placeholder{pointer-events:none;width:100%;max-width:100%;max-height:100%}.simplebar-height-auto-observer-wrapper{float:left;z-index:-1;pointer-events:none;flex-grow:inherit;flex-shrink:0;flex-basis:0;width:100%;max-width:1px;height:100%;max-height:1px;margin:0;padding:0;position:relative;overflow:hidden;box-sizing:inherit!important}.simplebar-height-auto-observer{box-sizing:inherit;opacity:0;pointer-events:none;z-index:-1;width:1000%;min-width:1px;height:1000%;min-height:1px;display:block;position:absolute;top:0;left:0;overflow:hidden}.simplebar-track{z-index:1;pointer-events:none;position:absolute;bottom:0;right:0;overflow:hidden}[data-simplebar].simplebar-dragging,[data-simplebar].simplebar-dragging .simplebar-content{pointer-events:none;-webkit-touch-callout:none;-webkit-user-select:none;user-select:none;-khtml-user-select:none}[data-simplebar].simplebar-dragging .simplebar-track{pointer-events:all}.simplebar-scrollbar{min-height:10px;position:absolute;left:0;right:0}.simplebar-scrollbar:before{content:"";opacity:0;background:#000;border-radius:7px;transition:opacity .2s linear .5s;position:absolute;left:2px;right:2px}.simplebar-scrollbar.simplebar-visible:before{opacity:.5;transition-duration:0s;transition-delay:0s}.simplebar-track.simplebar-vertical{width:11px;top:0}.simplebar-scrollbar:before{inset:2px}.simplebar-track.simplebar-horizontal{height:11px;left:0}.simplebar-track.simplebar-horizontal .simplebar-scrollbar{width:auto;min-width:10px;min-height:0;inset:0 auto 0 0}[data-simplebar-direction=rtl] .simplebar-track.simplebar-vertical{left:0;right:auto}.simplebar-dummy-scrollbar-size{opacity:0;visibility:hidden;direction:rtl;width:500px;height:500px;position:fixed;overflow:scroll hidden;-ms-overflow-style:scrollbar!important}.simplebar-dummy-scrollbar-size>div{width:200%;height:200%;margin:10px 0}.simplebar-hide-scrollbar{visibility:hidden;scrollbar-width:none;-ms-overflow-style:none;position:fixed;left:0;overflow-y:scroll}
