(globalThis.TURBOPACK||(globalThis.TURBOPACK=[])).push(["object"==typeof document?document.currentScript:void 0,997585,e=>{e.v("/_next/static/media/reload-image.7aa931c7.svg")},585190,(e,t,a)=>{"use strict";Object.defineProperty(a,"__esModule",{value:!0}),Object.defineProperty(a,"warnOnce",{enumerable:!0,get:function(){return l}});let l=e=>{}},153029,e=>{"use strict";var t=function(){var t="ampIntegrationContext";return"undefined"!=typeof globalThis&&void 0!==globalThis[t]?globalThis[t]:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof self?self:e.g};e.s(["getGlobalScope",()=>t])},18737,e=>{e.v(t=>Promise.all(["static/chunks/206d5d181e4c738e.js"].map(t=>e.l(t))).then(()=>t(962027)))},686224,e=>{e.v(t=>Promise.all(["static/chunks/5c4dfb0d09eaa401.js"].map(t=>e.l(t))).then(()=>t(817172)))},525120,e=>{e.v(t=>Promise.all(["static/chunks/b851a1d3f8149828.js"].map(t=>e.l(t))).then(()=>t(423142)))},197107,e=>{e.v(t=>Promise.all(["static/chunks/025a7e3e3f9f40ae.js"].map(t=>e.l(t))).then(()=>t(795773)))},33542,e=>{e.v(t=>Promise.all(["static/chunks/ee7f1a8227342421.js"].map(t=>e.l(t))).then(()=>t(576864)))}]);