(globalThis.TURBOPACK||(globalThis.TURBOPACK=[])).push(["object"==typeof document?document.currentScript:void 0,408821,e=>{"use strict";var r=e.i(19483),t=e.i(382875),o=e.i(671746),i=e.i(842858),n=e.i(415570),c=e.i(518550),s=e.i(542098),a=e.i(187725);function d({error:e,reset:d}){return(0,a.useEffect)(()=>{s.captureException(e,{tags:{errorBoundary:"app",digest:e.digest},extra:{componentStack:e.stack}}),console.error("App Error Boundary caught error:",e)},[e]),(0,r.jsx)(i.Center,{height:"100%",backgroundColor:"gray.50",children:(0,r.jsxs)(n.Flex,{p:4,direction:"column",justifyContent:"flex-start",backgroundColor:"white",border:"solid lightgray 1px",borderRadius:"md",minHeight:"200px",boxShadow:"md",children:[(0,r.jsx)(c.Heading,{width:"800px",size:"md",mb:4,children:"You have encountered an error"}),(0,r.jsx)(t.Box,{flex:"1",fontSize:"10pt",color:"gray.600",mb:4,children:e.message||String(e)}),e.digest&&(0,r.jsxs)(t.Box,{fontSize:"9pt",color:"gray.400",mb:4,children:["Error ID: ",e.digest]}),(0,r.jsx)(o.Button,{justifySelf:"center",alignSelf:"center",mt:"20px",colorPalette:"blue",size:"sm",onClick:()=>{d()},children:"Try again"})]})})}e.s(["default",()=>d])}]);