(globalThis.TURBOPACK||(globalThis.TURBOPACK=[])).push(["object"==typeof document?document.currentScript:void 0,829216,e=>{"use strict";var i=e.i(19483),t=e.i(918132),r=e.i(302061);function n(){return(0,i.jsx)(t.ReactFlowProvider,{children:(0,i.jsx)(r.LineageView,{interactive:!0})})}e.s(["LineagePage",()=>n])},753343,e=>{"use strict";var i=e.i(19483),t=e.i(829216);function r(){return(0,i.jsx)(t.LineagePage,{})}e.s(["default",()=>r])}]);